@@ -1,6 +1,9 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2013-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
+"""
+Adds blogging functionality. See :doc:`/plugins/blogs`.
+"""
 
 from lino.ad import Plugin, _
 
@@ -9,7 +12,7 @@ class Plugin(Plugin):
 
     verbose_name = _("Blog")
 
-    needs_plugins = ['lino_xl.lib.topics']
+    needs_plugins = ['lino_xl.lib.topics', 'lino.modlib.office']
 
     def setup_main_menu(self, site, user_type, m):
         # mg = self.get_menu_group()
