@@ -124,7 +124,7 @@ class Entry(UserAuthored, Controllable, CombinedDateTime,
     def item_preview(self, ar):
         return self.get_item_preview(ar)
 
-    def as_summary_row(self, ar):
+    def as_story_item(self, ar):
         return self.get_item_preview(ar)
 
     def get_preview_context(self, ar):
