@@ -56,7 +56,6 @@ class InsertEvent(dd.Action):
             start_date=str(ar.selected_rows[0].date))
         ar.set_response(eval_js=ar.renderer.ar2js(sar, None))
 
-
 class DailyPlannerRows(dd.Table):
     # used for configuring the planner rows
     model = 'calview.DailyPlannerRow'
@@ -264,6 +263,7 @@ class DayNavigator(DaysTable):
         # return cls.get_data_elem('day_number')
         return cls.day_number.return_type
 
+
 class CalendarView(DayNavigator):
     abstract = True
     use_detail_param_panel = True
@@ -345,9 +345,10 @@ class CalendarView(DayNavigator):
             *rows, align="center"), CLASS="cal-month-table")
 
         header = [
-            current_view(long_prev, "<<"), " " , current_view(short_prev, "<"),
+            # current_view(long_prev, "<<"), " " , current_view(short_prev, "<"),
             E.span(E.span("{} {}".format(monthname(today.month), today.year), E.br(), monthly_div)),
-            current_view(short_next, ">"), " ", current_view(long_next, ">>")]
+            # current_view(short_next, ">"), " ", current_view(long_next, ">>")
+        ]
         elems.append(E.h2(*header, align="center"))
         weekdaysFirstLetter = " " + "".join([gettext(week.text)[0] for week in Weekdays.objects()])
         rows = [E.tr(*[E.td(E.b(day_of_week)) for day_of_week in weekdaysFirstLetter], align='center')]
@@ -373,20 +374,38 @@ class CalendarView(DayNavigator):
                 else:
                     pk = date2pk(week[0])
                     txt = weekly(cls.get_row_by_pk(ar, pk), str(current_week))
-                cells = [ E.td(txt, CLASS="cal-week") ] + cells
+                cells = [ E.td(txt, CLASS="cal-week center") ] + cells
             rows.append(E.tr(*cells, align="center"))
 
         today = cls.get_row_by_pk(ar, 0)
         elems.append(E.table(*rows, align="center"))
         elems.append(E.p(daily(today, gettext("Today")), align="center"))
-        elems.append(E.p(weekly(today, gettext("This week")), align="center"))
-        elems.append(E.p(monthly(today, gettext("This month")), align="center"))
+        # elems.append(E.p(weekly(today, gettext("This week")), align="center"))
+        # elems.append(E.p(monthly(today, gettext("This month")), align="center"))
 
         # for o in range(-10, 10):
         #     elems.append(ar.goto_pk(o, str(o)))
         #     elems.append(" ")
         return E.div(*elems, CLASS="lino-nav-cal")
 
+    @classmethod
+    def collect_extra_actions(cls):
+        yield dd.WrappedAction(
+            rt.models.calview.DailyView.detail_action,
+            help_text=_("Show daily view."),
+            label=_("Daily"),
+            icon_name=None)
+        yield dd.WrappedAction(
+            rt.models.calview.WeeklyView.detail_action,
+            action_name='calview_weekly_wrapper',
+            help_text=_("Show weekly view."),
+            label=_("Weekly"),
+            icon_name=None)
+        yield dd.WrappedAction(
+            rt.models.calview.MonthlyView.detail_action,
+            help_text=_("Show monthly view."),
+            label=_("Monthly"),
+            icon_name=None)
 
 
 class DaySlave(AbstractTable):
@@ -476,7 +495,7 @@ class DaySlave(AbstractTable):
             yield str(self.project)
 
     @classmethod
-    def get_calview_div(cls, obj, ar):
+    def get_calview_div(cls, obj, ar, today=None, passed_style=None, mde=False):
         """Return a <div> for this calendar entry in the view given by ar.
 
         """
@@ -486,15 +505,21 @@ class DaySlave(AbstractTable):
 
         # text = E.span(*cls.get_calview_chunks(obj, ar))
         text = E.span(time_text, " ", *obj.get_event_summary(ar))
-        color = obj.get_diplay_color()
+        color = obj.get_display_color()
         if color:
-            dot  = E.span("\u00A0", CLASS="dot",
-                style="background-color: {};".format(color))
+            style = "background-color: {}; color: {}; ".format(color.value, color.font_color)
+            if passed_style:
+                style += passed_style
+            if mde:
+                style += " height: 1.2em;"
+                return E.div(text, style=style)
+            dot  = E.span("\u00A0", CLASS="dot", style=style)
             # ele.attrib['style'] = "color: white;background-color: {};".format(data_color)
             # dot.attrib['style'] = "background-color: {};".format(data_color)
-            return E.div(dot, text)
+            return E.div(dot, text, style="height: 1.2em;padding: 0 5px")
         else:
-            return E.div(text)
+            return E.div(text, style="height: 1.2em;padding: 0 5px")
+
 
 class DailySlaveBase(DaySlave, VentilatedColumns):
     abstract = True
@@ -524,7 +549,10 @@ class DailySlaveBase(DaySlave, VentilatedColumns):
                 mi = cls.calendar_view.get_row_by_pk(ar, 0)
             qs = cls.get_calendar_entries(ar, obj)
             qs = qs.filter(event_type__planner_column=pc)
-            qs = qs.filter(start_date=mi.date)
+            # qs = qs.filter(start_date=mi.date)
+            qs = qs.filter(models.Q(start_date=mi.date) |
+                models.Q(end_date__gte=mi.date, start_date__lte=mi.date))
+
             # pv = ar.param_values
             # qs = Event.calendar_param_filter(qs, pv)
             # current_day = pv.get('date', dd.today())
@@ -540,9 +568,10 @@ class DailySlaveBase(DaySlave, VentilatedColumns):
             #     if obj.end_time:
             #         qs = qs.filter(start_time__lt=obj.end_time,
             #                        start_time__isnull=False)
-            qs = qs.order_by('start_time')
+            qs = qs.order_by('start_date', 'start_time')
             chunks = [e.obj2href(ar, cls.get_calview_div(e, ar)) for e in qs]
-            return E.p(*join_elems(chunks))
+            return E.table(E.tr(E.td(E.div(*join_elems(chunks),
+                style="overflow: visible;"))), CLASS="fixed-table")
 
         return dd.VirtualField(dd.HtmlBox(pc.text), func)
 
@@ -582,14 +611,15 @@ class WeeklySlaveBase(DaySlave, VentilatedColumns):
             today = dd.today(delta_days)
             # current_week_day = current_day + \
             #     timedelta(days=int(week_day.value) - current_day.weekday() - 1)
+            # qs = qs.filter(start_date=today)
             qs = qs.filter(start_date=today)
             qs = qs.order_by('start_time')
             if obj is cls.model.HEADER_ROW:
                 chunks = obj.get_header_chunks(ar, qs, today)
             else:
                 chunks = obj.get_weekly_chunks(ar, qs, today)
-            return E.table(E.tr(E.td(E.div(*join_elems(chunks)))),
-                CLASS="fixed-table")
+            return E.table(E.tr(E.td(E.div(*join_elems(chunks),
+                style="overflow: visible;"))), CLASS="fixed-table")
 
         return dd.VirtualField(dd.HtmlBox(week_day.text), func)
 
@@ -635,9 +665,62 @@ class MonthlySlaveBase(DaySlave, VentilatedColumns):
             # if target_day is None:
             #     return
             # target_day = week[int(wd.value)-1]
-            qs = qs.filter(start_date=target_day.date)
+            # qs = qs.filter(start_date=target_day.date)
+            today = target_day.date
+            qs = qs.filter(start_date=today)
             qs = qs.order_by('start_time')
-            chunks = [E.p(e.obj2href(ar, cls.get_calview_div(e, ar))) for e in qs]
+
+            mdes = qs.filter(end_date__isnull=False)
+            mdes = mdes.order_by('-end_date')
+            qs = qs.filter(end_date__isnull=True)
+
+            if today.weekday() == 0 and (current_month > target_day.date.month
+                or target_day.date.day == 1):
+                cls.mde_pops = [[[] for i in range(7)] for i in range(5)]
+                cls.week_offset = target_day.date.isocalendar()[1] % 5
+
+            chunks = []
+            uncolored_mdes = []
+            week_index = (target_day.date.isocalendar()[1] - cls.week_offset) % 5
+
+            chunks += cls.mde_pops[week_index][today.weekday()]
+
+            for e in mdes:
+                color = e.get_display_color()
+                if not color:
+                    uncolored_mdes.append(e)
+                    continue
+                wi = week_index
+                days = (e.end_date - e.start_date).days
+                max_count = len(cls.mde_pops[wi][today.weekday()]) + 1
+                for i in range(days + 1):
+                    mde_pos = (today.weekday() + i) % 7
+                    wi = week_index + ((today.weekday() + i) // 7)
+                    if wi >= 5:
+                        break
+                    if mde_pos == 0 and i > 0:
+                        max_count = len(cls.mde_pops[wi][mde_pos]) + 1
+                        remains = days - i
+                        cols = 6 if remains >= 6 else remains
+                        style = (f"margin-right: -{100 * cols}%;" +
+                            "position: relative;padding: 0 5px;" +
+                            f"background: {color.value};color:{color.font_color};" +
+                            "border-radius: 5px;height: 1.2em;")
+                        cls.mde_pops[wi][mde_pos].append(e.obj2href(ar, E.div("\u00A0", style=style)))
+                    elif i != 0:
+                        cls.mde_pops[wi][mde_pos].append(E.div("\u00A0", style="height: 1.2em;"))
+                        elem_count = len(cls.mde_pops[wi][mde_pos])
+                        if elem_count < max_count:
+                            for i in range(max_count - elem_count):
+                                cls.mde_pops[wi][mde_pos].append(E.div("\u00A0", style="height: 1.2em;"))
+                cols = 6 - today.weekday() if days + today.weekday() > 7 else days
+                style = f"margin-right: -{100 * cols}%;position: relative;padding: 0 5px;border-radius: 5px;"
+                chunks.append(e.obj2href(ar, cls.get_calview_div(e, ar, today, passed_style=style, mde=True)))
+
+            for e in uncolored_mdes:
+                chunks.append(e.obj2href(ar, cls.get_calview_div(e, ar, today)))
+
+            chunks += [e.obj2href(ar, cls.get_calview_div(e, ar, today)) for e in qs]
 
             # pk = date2pk(target_day)
 
@@ -663,7 +746,7 @@ class MonthlySlaveBase(DaySlave, VentilatedColumns):
                 header_items.append(btn)
 
             header = E.div(*header_items, align="center", CLASS="header" )
-            return E.table(E.tr(E.td(*[header, E.div(*join_elems(chunks))])),
+            return E.table(E.tr(E.td(*[header, E.div(*join_elems(chunks), style="overflow: visible;")])),
                            CLASS="fixed-table cal-month-cell {} {} {}".format(
                              "current-month" if current_month == target_day.date.month else "other-month",
                              "current-day" if target_day.date == today else "",
