@@ -26,12 +26,15 @@ from lino.utils.media import TmpMediaFile
 from lino_xl.lib.addresses.mixins import AddressOwner
 from lino_xl.lib.phones.mixins import ContactDetailsOwner
 from lino_xl.lib.skills.mixins import Feasible
+from lino_xl.lib.vat.choicelists import VatSubjectable
 
 from .choicelists import CivilStates
 from .roles import SimpleContactsUser, ContactsStaff
 from .choicelists import PartnerEvents
 
 if dd.plugins.contacts.use_vcard_export:
+    from lino.modlib.uploads.mixins import UploadBase
+    from lino_xl.lib.countries.wikidata import get_countries
     try:
         import vobject
     except ImportError:
@@ -40,11 +43,110 @@ if dd.plugins.contacts.use_vcard_export:
         #     "use_vcard_export is True but vobject is not installed")
         vobject = None
 
+    class UploadVCardFile(UploadBase):
+
+        class Meta(object):
+            app_label = 'contacts'
+            verbose_name = _("vCard File")
+            verbose_name_plural = _("vCard Files")
+
+        description = dd.CharField(max_length=10, blank=True, verbose_name=_('Description'))
+
+        def save_newly_uploaded_file(self, uf):
+            if not str(uf).endswith('.vcf'):
+                raise ValidationError(_("Invalid File Type"))
+            countries = get_countries()
+            Country = rt.models.countries.Country
+            Place = rt.models.countries.Place
+            Person = rt.models.contacts.Person
+            for vo in vobject.readComponents(uf.read().decode()):
+                if not hasattr(vo, 'n'): continue
+                p = Person()
+                p.first_name = vo.n.value.given
+                p.middle_name = vo.n.value.additional
+                p.last_name = vo.n.value.family
+                if hasattr(vo, 'email'):
+                    p.email = vo.email.value
+                    emails = []
+                    for e in vo.contents['email']:
+                        emails.append(e.value)
+                if hasattr(vo, 'tel'):
+                    p.phone = vo.tel.value
+                    tels = []
+                    for t in vo.contents['tel']:
+                        tels.append(t.value)
+                if hasattr(vo, 'adr'):
+                    p.street_box = vo.adr.value.box
+                    p.zip_code = vo.adr.value.code
+                    country = vo.adr.value.country
+                    kw = dict()
+                    if country != "":
+                        iso = country.lower()
+                        country, created = Country.objects.get_or_create(isocode=country)
+                        if created:
+                            country.name=countries['data'][iso]['name']
+                            country.full_clean()
+                            country.save()
+                        kw.update(country=country)
+                    p.country = country
+                    city = vo.adr.value.city
+                    if city != "":
+                        city, created = Place.objects.get_or_create(name=city, **kw)
+                        if created:
+                            city.full_clean()
+                            city.save()
+                    p.city = city
+                    region = vo.adr.value.region
+                    if region != "":
+                        region, created = Place.objects.get_or_create(name=region, **kw)
+                        if created:
+                            region.full_clean()
+                            region.save()
+                    p.street = vo.adr.value.street
+                    p.addr2 = vo.adr.value.extended # Address Line 2
+                if hasattr(vo, 'bday'):
+                    bday = vo.bday.value
+                    year = bday[:4]
+                    month = bday[4:6]
+                    day = bday[6:]
+                    p.birth_date = '.'.join([day, month, year])
+                if hasattr(vo, 'org'):
+                    org = vo.org.value
+                    org_name = org[0]
+                    if len(org) > 1:
+                        designation = org[1]
+                    if hasattr(vo, 'title'):
+                        title = vo.title.value
+                if hasattr(vo, 'url'):
+                    url = vo.url.value
+                    if not url.startswith('http'):
+                        url = 'https://' + url
+                    p.url = url
+                p.full_clean()
+                p.save()
+
+        def save(self, *args, **kwargs):
+            """
+            We don't want to save any object instance of this model. We mimic
+            the behaviour of saving just by settings the primary key to some
+            value."""
+            self.pk = 0
+
+    class UploadVCardFiles(dd.Table):
+        required_roles = dd.login_required(SimpleContactsUser)
+        model = 'contacts.UploadVCardFile'
+        insert_layout = """
+        file
+        description
+        """
+
 with_roles_history = dd.plugins.contacts.with_roles_history
 
 
 PARTNER_NUMBERS_START_AT = 100  # used for generating demo data and tests
 
+
+
 class ExportVCardFile(dd.Action):
     label = _("Export as vCard")
     icon_name = 'vcard'
@@ -124,7 +226,8 @@ class ImportText(dd.Action):
 
 
 class Partner(Duplicable, ContactDetailsOwner, mixins.Polymorphic,
-              AddressOwner, UploadController, Feasible, Printable, DateRangeObservable):
+              AddressOwner, UploadController, Feasible, Printable,
+              DateRangeObservable, VatSubjectable):
     preferred_foreignkey_width = 20
     # preferred width for ForeignKey fields to a Partner
 
@@ -467,6 +570,20 @@ class Persons(Partners):
     overview
     """
 
+    @classmethod
+    def collect_extra_actions(cls):
+        if dd.plugins.contacts.use_vcard_export:
+            yield dd.WrappedAction(
+                UploadVCardFiles.insert_action,
+                help_text=_("Import contacts from vCard File."),
+                label=_("Import from VCard"),
+                icon_name=None,
+                select_rows=False,
+                callable_from='dt',
+                sort_index=-8)
+        else:
+            return []
+
 
 class CompanyType(mixins.BabelNamed):
     class Meta(object):
