@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import datetime
@@ -11,7 +11,6 @@ from unipath import Path
 from django.conf import settings
 from lino.utils import Cycler
 from lino.api import dd, rt
-from etgen.sepa.validate import validate_pain001
 from lino_xl.lib.sepa.fixtures.sample_ibans import IBANS
 
 finan = dd.resolve_app('finan')
@@ -146,12 +145,6 @@ def objects(refs="PMO BNK"):  # welfare calls it with customized refs.
                     rv = voucher.write_xml.run_from_session(ses)
                     if not rv['success']:
                         raise Exception("20170630")
-                    if False:
-                        # not needed here because write_xml validates
-                        fn = Path(settings.SITE.cache_dir + rv['open_url'])
-                        if not fn.exists():
-                            raise Exception("20170630")
-                        validate_pain001(fn)
 
             date += delta(months=1)
         # JOURNAL_BANK = Journal.objects.get(ref="BNK")
