@@ -157,7 +157,6 @@ class VatProductInvoice(SalesDocument, Matching):
             yield f
         yield 'due_date'
         # yield 'order'
-
         yield 'voucher_date'
         yield 'entry_date'
         yield 'user'
@@ -190,7 +189,7 @@ class InvoiceDetail(dd.DetailLayout):
     main = "general more ledger"
 
     general = dd.Panel("""
-    panel1:30 panel3:30 panel2 totals:20
+    panel1:20 panel2:30 panel3:25 totals:20
     ItemsByInvoice
     """, label=_("General"))
 
@@ -213,7 +212,7 @@ class InvoiceDetail(dd.DetailLayout):
 
     panel1 = dd.Panel("""
     entry_date
-    #order subject
+    # order subject
     payment_term
     due_date:20
     """)
@@ -222,10 +221,11 @@ class InvoiceDetail(dd.DetailLayout):
     partner
     subject
     vat_regime
-    your_ref match
+    your_ref
     """)
 
     panel3 = dd.Panel("""
+    match
     payment_method
     paper_type
     printed
