@@ -1,19 +1,26 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from decimal import Decimal
+from os.path import join, dirname
 
 from django.conf import settings
 from django.db import models
 from django.core.exceptions import ValidationError
 
+from django.db import models
+from django.db.models import Q, F, Sum, Subquery, OuterRef, Exists, Case, Value, When
+from django.db.models.functions import Cast
+
+
 from lino.utils import SumCollector
 # from lino.utils.dates import AMONTH, ADAY
 from lino.api import dd, rt, _
 # from lino.mixins.registrable import Registrable
 
 from lino_xl.lib.ledger.choicelists import CommonAccounts
+from lino_xl.lib.ledger.choicelists import TradeTypes
 from lino_xl.lib.ledger.mixins import ProjectRelated, VoucherItem
 from lino_xl.lib.ledger.mixins import Payable
 from lino_xl.lib.ledger.models import RegistrableVoucher, VoucherStates
@@ -21,7 +28,6 @@ from lino_xl.lib.ledger.utils import ZERO, ONE, myround
 
 from .choicelists import VatClasses, VatRegimes, VatAreas, VatRules
 
-ledger = dd.resolve_app("ledger")
 
 class PartnerDetailMixin(dd.DetailLayout):
     """
@@ -257,7 +263,7 @@ class VatDocument(RegistrableVoucher, ProjectRelated, VatTotal):
 
     @dd.chooser()
     def vat_regime_choices(self, partner):
-        return rt.models.vat.get_vat_regime_choices(partner.country)
+        return VatRegimes.get_choices_for_country(partner.country)
 
     def partner_changed(self, ar=None):
         self.vat_regime = None
@@ -333,11 +339,12 @@ class VatItemBase(VoucherItem, VatTotal):
 
     def vat_class_changed(self, ar):
         # dd.logger.info("20121204 vat_class_changed")
-        # if self.voucher.vat_regime.item_vat:
-        if dd.plugins.vat.item_vat:
-            self.total_incl_changed(ar)
-        else:
-            self.total_base_changed(ar)
+        self.reset_totals(ar) # #4291 (partly deducible VAAT)
+        # # if self.voucher.vat_regime.item_vat:
+        # if dd.plugins.vat.item_vat:
+        #     self.total_incl_changed(ar)
+        # else:
+        #     self.total_base_changed(ar)
 
     def get_base_account(self, tt):
         raise NotImplementedError
@@ -452,6 +459,8 @@ class QtyVatItemBase(VatItemBase):
                 self.set_amount(ar, myround(self.unit_price * self.qty))
 
 
+ledger = dd.resolve_app("ledger")
+
 class VatDeclaration(ledger.Declaration):
 
     class Meta:
@@ -509,3 +518,117 @@ class VatDeclaration(ledger.Declaration):
             v = getattr(self, fld.name)
             if v:
                 print("[{}] {} : {}".format(fld.value, fld.help_text, v))
+
+    def intracom_statement_iterator(self):
+        intracom_regimes = set([
+            r for r in VatRegimes.get_list_items() if r.vat_area == VatAreas.eu])
+
+        def annotator():
+
+            def build_case(model):
+
+                def get_filter():
+                    filter_kw = dict(
+                        partner__pk=OuterRef('pk'),
+                        journal__trade_type=TradeTypes.sales,
+                        vat_regime__in=intracom_regimes
+                    )
+                    filter_kw.update(self.get_period_filter(""))
+                    return filter_kw
+
+                return Case(
+                    When(~Exists(model.objects.filter(
+                        **get_filter()
+                    ).values('pk')), then=Value(0.0)),
+                    default=Subquery(
+                        model.objects.filter(
+                            **get_filter()
+                        ).order_by().values('partner').annotate(
+                            total_by_partner=Sum('total_base')
+                        ).values('total_by_partner')
+                    ),
+                    output_field=models.DecimalField()
+                )
+
+            kw = dict(vai_base=build_case(rt.models.vat.VatAccountInvoice))
+            if dd.is_installed('sales'):
+                kw['vpi_base'] = build_case(rt.models.sales.VatProductInvoice)
+            else:
+                kw['vpi_base'] = Cast(
+                    Value(0.0), output_field=models.DecimalField())
+            return kw
+
+        qs = rt.models.contacts.Partner.objects.annotate(
+            **annotator()
+        ).annotate(
+            total_base=F('vai_base') + F('vpi_base')
+        ).filter(total_base__gt=0)
+
+        for p in qs:
+            yield p
+
+    def unused_intracom_statement_iterator(self):
+        # AccountingPeriod = rt.models.ledger.AccountingPeriod
+        intracom_regimes = set([
+            r for r in VatRegimes.get_list_items() if r.vat_area == VatAreas.eu])
+        # ap = AccountingPeriod.objects.get(ref="2014-02")
+        qs = rt.models.contacts.Partner.objects.all()
+        # qs = qs.filter(vat_id__isnull=False)
+        # qs = qs.exclude(vat_id__startswith="BE")
+        qs = qs.order_by('vat_id').distinct()
+        if False:
+            qs = qs.annotate(total_base=Sum('ledger_movement_set_by_partner__amount'))
+            qs = qs.filter(
+                ledger_movement_set_by_partner__journal__trade_type=TradeTypes.sales,
+                # ledger_movement_set_by_partner__accounting_period=ap,
+                ledger_movement_set_by_partner__vat_regime__in=intracom_regimes,
+                total_base__gte=0,
+                **self.get_period_filter('ledger_movement_set_by_partner__'))
+            return qs
+        else:
+            if True:
+                qs = qs.annotate(vataccountinvoice_base=Sum(
+                    'vat_vataccountinvoice_set_by_partner__total_base',
+                    filter=Q(
+                        vat_vataccountinvoice_set_by_partner__journal__trade_type=TradeTypes.sales,
+                        # vat_vataccountinvoice_set_by_partner__accounting_period=ap,
+                        vat_vataccountinvoice_set_by_partner__vat_regime__in=intracom_regimes,
+                        **self.get_period_filter('vat_vataccountinvoice_set_by_partner__')
+                    )
+                ))#.filter(vataccountinvoice_base__gte=0)
+
+            # qs = qs.annotate(vataccountinvoice_base=Sum('vat_vataccountinvoice_set_by_partner__total_base',))
+            # flt1 = Q(
+            #     vat_vataccountinvoice_set_by_partner__journal__trade_type=TradeTypes.sales,
+            #     # vat_vataccountinvoice_set_by_partner__accounting_period=ap,
+            #     vat_vataccountinvoice_set_by_partner__vat_regime__in=intracom_regimes,
+            #     vataccountinvoice_base__gte=0,
+            #     **self.get_period_filter('vat_vataccountinvoice_set_by_partner__'))
+
+            if dd.is_installed("sales") and True:
+                qs = qs.annotate(vatproductinvoice_base=Sum(
+                    'sales_vatproductinvoice_set_by_partner__total_base',
+                    filter=Q(
+                        sales_vatproductinvoice_set_by_partner__journal__trade_type=TradeTypes.sales,
+                        # sales_vatproductinvoice_set_by_partner__accounting_period=ap,
+                        sales_vatproductinvoice_set_by_partner__vat_regime__in=intracom_regimes,
+                        **self.get_period_filter('sales_vatproductinvoice_set_by_partner__')
+                    )
+                ))#.filter(vatproductinvoice_base__gte=0)
+                # qs = qs.annotate(total_base=Sum(F('vatproductinvoice_base'), F('vataccountinvoice_base')))
+            # else:
+            #     qs = qs.filter(flt1)
+                # qs = qs.annotate(total_base=F('vataccountinvoice_base'))
+            # print("20210903", str(qs.query).replace('"', ''))
+            # from pprint import pprint
+            # print(qs.query)
+            # qs = qs.order_by('vat_id').distinct()
+            qs.annotate(total_base=F('vataccountinvoice_base') + F('vatproductinvoice_base')).filter(total_base__gte=0)
+            return qs
+            # for p in qs:
+            #     # p.total_base = 0
+            #     # if True:
+            #     #     p.total_base += p.vataccountinvoice_base or ZERO
+            #     # if dd.is_installed("sales") and True:
+            #     #     p.total_base += p.vatproductinvoice_base
+            #     yield p
