@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2020 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.conf import settings
@@ -41,47 +41,23 @@ class InvoiceItem(AccountVoucherItem, VatItemBase):
         if self.account and self.account.vat_class:
             self.vat_class = self.account.vat_class
 
-if False:
-    """Install a post_init signal listener for each concrete subclass of
-    VatDocument.  The following trick worked...  but best is to store
-    it in VatRegime, not per voucher.
+# if False:
+#     """Install a post_init signal listener for each concrete subclass of
+#     VatDocument.  The following trick worked...  but best is to store
+#     it in VatRegime, not per voucher.
+#
+#     """
+#
+#     def set_default_item_vat(sender, instance=None, **kwargs):
+#         instance.item_vat = settings.SITE.get_item_vat(instance)
+#         # print("20130902 set_default_item_vat", instance)
+#
+#     @dd.receiver(dd.post_analyze)
+#     def on_post_analyze(sender, **kw):
+#         for m in rt.models_by_base(VatDocument):
+#             dd.post_init.connect(set_default_item_vat, sender=m)
+#             # print('20130902 on_post_analyze installed receiver for',m)
 
-    """
-
-    def set_default_item_vat(sender, instance=None, **kwargs):
-        instance.item_vat = settings.SITE.get_item_vat(instance)
-        # print("20130902 set_default_item_vat", instance)
-
-    @dd.receiver(dd.post_analyze)
-    def on_post_analyze(sender, **kw):
-        for m in rt.models_by_base(VatDocument):
-            dd.post_init.connect(set_default_item_vat, sender=m)
-            # print('20130902 on_post_analyze installed receiver for',m)
-
-
-dd.inject_field(
-    'contacts.Partner', 'vat_regime', VatRegimes.field(blank=True))
-
-
-def get_vat_regime_choices(country=None):
-    vat_area = VatAreas.get_for_country(country)
-    # print("20190405", vat_area)
-    for r in VatRegimes.get_list_items():
-        if vat_area is None or r.vat_area is None or r.vat_area == vat_area:
-            yield r
-
-@dd.chooser()
-def partner_vat_regime_choices(cls, country):
-    return get_vat_regime_choices(country)
-
-
-dd.inject_action(
-    'contacts.Partner',vat_regime_choices=partner_vat_regime_choices)
-
-dd.inject_field(
-    'contacts.Partner',
-    'vat_id',
-    models.CharField(_("VAT id"), max_length=200, blank=True))
 
 dd.inject_field(
     'ledger.Movement', 'vat_regime', VatRegimes.field(blank=True))
