@@ -21,7 +21,7 @@ class Votable(ChangeNotifier):
         abstract = True
 
     if dd.is_installed('votes'):
-    
+
         create_vote = CreateVote()
         edit_vote = VotableEditVote()
 
@@ -68,13 +68,13 @@ class Votable(ChangeNotifier):
             #     if user in wanted_votes:
             #         return
             for user in self.get_vote_raters():
+                new_values = dict(user=user, votable=self)
+                if dd.plugins.votes.use_candidatures:
+                    new_values.update(state=VoteStates.author)
                 create_or_update_row(
                     rt.models.votes.Vote,
-                    dict(user=user,
-                         votable=self),
-                    dict(user=user,
-                         votable=self,
-                         state=VoteStates.author)
+                    dict(user=user, votable=self),
+                    new_values
                 )
 
             # for user, state in wanted_votes.items():
